package sun.misc;

import jdk.internal.util.EnvUtils;
import java.security.AccessController;
import java.security.PrivilegedAction;
import java.io.File;
import sun.usagetracker.UsageTrackerClient;

public class PostVMInitHook
{
    private static final String ORCL_UT_CONFIG_FILE_NAME = "usagetracker.properties";
    
    public PostVMInitHook() {
    }
    
    public static void run() {
        trackJavaUsage();
    }
    
    private static void trackJavaUsage() {
        String property = System.getProperty("os.name");
        if (getConfigFilePrivileged() != null || property.toLowerCase().startsWith("win") || property.contains("OS X")) {
            new UsageTrackerClient().run("VM start", System.getProperty("sun.java.command"));
        }
    }
    
    private static File getConfigFilePrivileged() {
        File file = null;
        String[] array;
        for (String s : array = new String[] { System.getProperty("com.oracle.usagetracker.config.file"), getOSSpecificConfigFilePath(), System.getProperty("java.home") + File.separator + "conf" + File.separator + "management" + File.separator + "usagetracker.properties" }) {
            if (s != null) {
                file = (File)AccessController.doPrivileged(new PrivilegedAction<File>() {
                    @Override
                    public File run() {
                        File file = new File(s);
                        return file.exists() ? file : null;
                    }
                });
                if (file != null) {
                    break;
                }
            }
        }
        return file;
    }
    
    private static String getOSSpecificConfigFilePath() {
        String property = System.getProperty("os.name");
        if (property != null) {
            String lowerCase = property.toLowerCase();
            if (lowerCase.startsWith("sunos")) {
                return "/etc/oracle/java/usagetracker.properties";
            }
            if (lowerCase.startsWith("mac")) {
                return "/Library/Application Support/Oracle/Java/usagetracker.properties";
            }
            if (lowerCase.startsWith("win")) {
                String envPrivileged = getEnvPrivileged("ProgramData");
                return (envPrivileged == null) ? null : (envPrivileged + "\\Oracle\\Java\\" + "usagetracker.properties");
            }
            if (lowerCase.startsWith("linux")) {
                return "/etc/oracle/java/usagetracker.properties";
            }
        }
        return null;
    }
    
    private static String getEnvPrivileged(final String s) {
        return (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return EnvUtils.getEnvVar(s);
            }
        });
    }
}
